@@ -6,3 +6,7 @@
 #'
 #' @export
 str_split_camel_case <- strex::str_split_camel_case
+
+#' @rdname str_split_camel_case
+#' @export
+split_camel_case <- str_split_camel_case
